<?php

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb)
{
	if (!empty ($breadcrumb))
	{
		return '<div class="breadcrumb">' . implode(' ›› ', $breadcrumb) . '</div>';
	}
}

/**
 * Allow themable wrapping of all comments.
 */
function phptemplate_comment_wrapper($content, $node)
{
	if (!$content || $node->type == 'forum')
	{
		return '<div id="comments">' . $content . '</div>';
	}
	else
	{
		return '<div id="comments"><h2 class="comments">' . t('Comments') . '</h2>' . $content . '</div>';
	}
}

/**
 * Override or insert PHPTemplate variables into the templates.
 */
function phptemplate_preprocess_page(& $vars)
{
	$vars['tabs2'] = menu_secondary_local_tasks();

	// Hook into color.module
	if (module_exists('color'))
	{
		_color_page_alter($vars);
	}

	$css = $vars['css'];
	//unset ($css['all']['module']['modules/system/system.css']);
	unset ($css['all']['module']['modules/system/defaults.css']);
	$vars['styles'] = drupal_get_css($css);
	
}

/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs. Overridden to split the secondary tasks.
 *
 * @ingroup themeable
 */
function phptemplate_menu_local_tasks()
{
	if (theme_get_setting('inline_title')) {
	
		$tabs = explode("<li",menu_primary_local_tasks());
	
		// Invert the tabs so the first one will be last
		$tabs = array_reverse($tabs);
		
		foreach ($tabs as $k=>$v)
		{
			// Re-append the explode delimiter
			if (!empty($v)) @$html .= '<li'.$v;
		}
		return $html;
	}
	else return menu_primary_local_tasks();
}

/**
 * Generates IE CSS links for LTR and RTL languages.
 */
function phptemplate_get_ie_styles()
{
	global $language;

	$iecss = '<link type="text/css" rel="stylesheet" media="all" href="' . base_path() . path_to_theme() . '/fix-ie.css" />';

	// Right to left text support
	if (defined('LANGUAGE_RTL') && $language->direction == LANGUAGE_RTL)
	{
		$iecss .= '<style type="text/css" media="all">@import "' . base_path() . path_to_theme() . '/fix-ie-rtl.css";</style>';
	}

	return $iecss;
}